#
# Fedora spec file for php-aws-sdk
#
# Copyright (c) 2013-2016 Joseph Marrero <jmarrero@fedoraproject.org>
#                         Gregor Tätzner <brummbq@fedoraproject.org>
#                         Shawn Iwinski <shawn.iwinski@gmail.com>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     aws
%global github_name      aws-sdk-php
%global github_version   2.8.31
%global github_commit    64fa4b07f056e338a5f0f29eece75babaa83af68

%global composer_vendor  aws
%global composer_project aws-sdk-php

%global pear_channel     pear.amazonwebservices.com
%global pear_name        sdk

# "php": ">=5.3.3"
%global php_min_ver 5.3.3
# "guzzle/guzzle": "~3.7"
#     NOTE: Min version not 3.7 because autoloader required
%global guzzle_min_ver 3.9.3
%global guzzle_max_ver 4.0
# "doctrine/cache": "~1.0"
#     NOTE: Min version not 1.0 because autoloader required
%global doctrine_cache_min_ver 1.4.1
%global doctrine_cache_max_ver 2.0
# "monolog/monolog": "~1.4"
#     NOTE: Min version not 1.4 because autoloader required
%global monolog_min_ver  1.15.0
%global monolog_max_ver  2.0
# "symfony/yaml": "~2.1"
#     NOTE: Min version not 2.1 because autoloader required
%global symfony_min_ver %{?el6:2.3.31}%{!?el6:2.7.1}
%global symfony_max_ver 3.0

%{!?phpdir:  %global phpdir  %{_datadir}/php}

Name:      php-aws-sdk
Version:   %{github_version}
Release:   6%{?dist}
Summary:   Amazon Web Services framework for PHP

Group:     Development/Libraries
License:   ASL 2.0
URL:       http://aws.amazon.com/sdk-for-php/
Source0:   https://github.com/%{github_owner}/%{github_name}/archive/%{github_commit}/%{name}-%{github_version}-%{github_commit}.tar.gz

BuildArch: noarch
# Library version value and autoloader check
BuildRequires: php-cli
BuildRequires: php-composer(guzzle/guzzle) >= %{guzzle_min_ver}
BuildRequires: php-composer(fedora/autoloader)

# composer.json
Requires:  php(language)               >= %{php_min_ver}
Requires:  php-composer(guzzle/guzzle) >= %{guzzle_min_ver}
Requires:  php-composer(guzzle/guzzle) <  %{guzzle_max_ver}
# composer.json: optional
Requires:  php-openssl
# phpcompatinfo (computed from version 2.8.31)
Requires:  php-curl
Requires:  php-date
Requires:  php-hash
Requires:  php-json
Requires:  php-pcre
Requires:  php-reflection
Requires:  php-session
Requires:  php-simplexml
Requires:  php-spl
# Autoloader
Requires:  php-composer(fedora/autoloader)

# Weak dependencies
%if 0%{?fedora} >= 21
Suggests:  php-composer(doctrine/cache)
Suggests:  php-composer(monolog/monolog)
Suggests:  php-composer(symfony/yaml)
Suggests:  php-pecl(apcu)
%endif
Conflicts: php-doctrine-cache <  %{doctrine_cache_min_ver}
Conflicts: php-doctrine-cache >= %{doctrine_cache_max_ver}
Conflicts: php-Monolog        <  %{monolog_min_ver}
Conflicts: php-Monolog        >= %{monolog_max_ver}
Conflicts: php-symfony-yaml   <  %{symfony_min_ver}
Conflicts: php-symfony-yaml   >= %{symfony_max_ver}

# Composer
Provides:  php-composer(%{composer_vendor}/%{composer_project}) = %{version}
# PEAR
Provides:  php-pear(%{pear_channel}/%{pear_name}) = %{version}

# This pkg was the only one in this channel so the channel is no longer needed
Obsoletes: php-channel-aws

%description
Amazon Web Services SDK for PHP enables developers to build solutions for
Amazon Simple Storage Service (Amazon S3), Amazon Elastic Compute Cloud
(Amazon EC2), Amazon SimpleDB, and more.

Autoloader: %{phpdir}/Aws/autoload.php


%prep
%setup -qn %{github_name}-%{github_commit}

: Create autoloader
cat <<'AUTOLOAD' | tee src/Aws/autoload.php
<?php
/**
 * Autoloader for %{name} and its' dependencies
 * (created by %{name}-%{version}-%{release}).
 *
 */

require_once '%{_datadir}/php/Fedora/Autoloader/autoload.php';

\Fedora\Autoloader\Autoload::addPsr4('Aws\\', __DIR__);

\Fedora\Autoloader\Dependencies::required(array(
    '%{phpdir}/Guzzle/autoload.php',
));

\Fedora\Autoloader\Dependencies::optional(array(
    '%{phpdir}/Doctrine/Common/Cache/autoload.php',
    '%{phpdir}/Monolog/autoload.php',
    '%{phpdir}/Symfony/Component/Yaml/autoload.php',
));

AUTOLOAD


%build
# Empty build section, nothing required


%install
mkdir -p %{buildroot}%{phpdir}/AWSSDKforPHP
cp -pr src/* %{buildroot}%{phpdir}/
: Compat directory structure with old PEAR pkg
ln -s ../Aws %{buildroot}%{phpdir}/AWSSDKforPHP/Aws


%check
: Library version value and autoloader check
%{_bindir}/php -r '
    require_once "%{buildroot}%{phpdir}/Aws/autoload.php";
    $version = \Aws\Common\Aws::VERSION;
    echo "Version $version (expected %{version})\n";
    exit(version_compare("%{version}", "$version", "=") ? 0 : 1);
'

# Tests skipped because "Guzzle\Tests\GuzzleTestCase" is not provided by the
# php-guzzle-Guzzle package


%post
# Unregister PEAR pkg (ignore errors if it was not registered)
if [ -x %{_bindir}/pear ]; then
    %{_bindir}/pear uninstall --nodeps --ignore-errors --register-only \
        %{pear_channel}/%{pear_name} >/dev/null || :
fi


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE.md
%doc composer.json
%{phpdir}/Aws
%{phpdir}/AWSSDKforPHP


%changelog
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.8.31-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.8.31-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.8.31-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed May 10 2017 Valentin Collet <valentin@famillecollet.com> - 2.8.31-3
- Switch to fedora/autoloader

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.8.31-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Aug 08 2016 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.8.31-1
- Updated to 2.8.31 (RHBZ #1359963)

* Sat Jul 23 2016 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.8.30-1
- Updated to 2.8.30 (RHBZ #1359344)
- Updated weak dependency conflicts to use actual pkg names instead of
  php-composer(*) virtual provides
- Updated autoloader to not use "@include_once"

* Sun Mar 27 2016 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.8.27-1
- Updated to 2.8.27 (RHBZ #1320697)
- Added weak dependencies
- Autoloader updated to use dependencies' autoloaders
- Added library version value and autoloader check

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.8.21-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Oct 11 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.8.21-1
- Updated to 2.8.21 (RHBZ #1264060)

* Sat Sep 05 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.8.20-1
- Updated to 2.8.20 (RHBZ #1253094)
- Updated autoloader to load dependencies after self registration

* Tue Aug 04 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.8.17-1
- Updated to 2.8.17 (RHBZ #1243181)

* Fri Jul 10 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.8.13-2
- Use full require paths in autoloader

* Fri Jul 10 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.8.13-1
- Updated to 2.8.13 (RHBZ #1213030)
- Updated dependencies to use php-composer(*)
- Added autoloader

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.8.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Apr 25 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.8.2-1
- Updated to 2.8.2 (BZ #1213030)

* Sun Apr 12 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.8.0-1
- Updated to 2.8.0 (BZ #1192383)

* Thu Jan 29 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.7.17-1
- Updated to 2.7.17 (BZ #1180500)

* Sun Dec 28 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.7.12-1
- Updated to 2.7.12 (BZ #1171050)

* Tue Nov 25 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.7.6-1
- Updated to 2.7.6 (BZ #1164158)

* Sun Nov 09 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.7.3-1
- Updated to 2.7.3 (BZ #1157501)

* Mon Oct 20 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.7.1-1
- Updated to 2.7.1 (BZ #1151012)
- Doctrine Cache, Monolog, and Symfony YAML are now optional

* Tue Sep 23 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.6.16-1
- Updated to 2.6.16 (BZ #1142985)

* Sun Aug 17 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.6.15-2
- Obsolete php-channel-aws
- Compat direcory structure with old PEAR pkg

* Fri Aug 15 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.6.15-1
- Updated to 2.6.15 (BZ #1126610)
- PEAR install changed to Composer-ish install

* Mon Aug 04 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.6.1-3
- Fix php-guzzle-Guzzle max version (3.9.0 => 3.9.9)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun May 04 2014 Joseph Marrero <jmarrero@fedoraproject.org> - 2.6.1-1
- Update to latest upstream release

* Sun Mar 16 2014 Joseph Marrero <jmarrero@fedoraproject.org> - 2.5.3-1
- Update to latest upstream release

* Fri Feb 21 2014 Joseph Marrero <jmarrero@fedoraproject.org> - 2.5.2-1
- Update to latest upstream release

* Fri Jan 03 2014 Joseph Marrero <jmarrero@fedoraproject.org> - 2.5.0-5
- Remove the aws.phar with other uneaded files on %%install

* Fri Jan 03 2014 Joseph Marrero <jmarrero@fedoraproject.org> - 2.5.0-4
- Keep the aws.phar file for workaround on install

* Thu Jan 02 2014 Joseph Marrero <jmarrero@fedoraproject.org> - 2.5.0-3
- Fix file installation

* Mon Dec 30 2013 Joseph Marrero <jmarrero@fedoraproject.org> - 2.5.0-2
- add php-Monolog-dynamo dependency
- update naming on dependency php-symfony-yaml
- fix max version require on guzzle dependency

* Sun Dec 29 2013 Joseph Marrero <jmarrero@fedoraproject.org> - 2.5.0-1
- update to latest upstrean version

* Mon Nov 18 2013 Joseph Marrero <jmarrero@fedoraproject.org> - 2.4.10-1
- update to latest upstream version
- add php-symfony2-Yaml(version2) and php-Monolog
- remove dependency php-symfony2-YAML(version1)
- set version contraint for php-guzzle-Guzzle dependency

* Mon Sep 09 2013 Joseph Marrero <jmarrero@fedoraproject.org> - 2.4.5-2
- add guzzle dependency.
- remove aws.phar file

* Thu Sep 05 2013 Joseph Marrero <jmarrero@fedoraproject.org> - 2.4.5-1
- Update to 2.4.5

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed May 08 2013 Gregor Tätzner <brummbq@fedoraproject.org> - 1.6.2-5
- unbundle sfyaml
- fix requires
- mark doc in package.xml

* Wed May 01 2013 Joseph Marrero <jmarrero@fedoraproject.org> - 1.6.2-4
- Add dependencies
- Add license clarification

* Tue Apr 30 2013 Joseph Marrero <jmarrero@fedoraproject.org> - 1.6.2-3
- Fix Source, remove empty folder _doc

* Mon Apr 29 2013 Joseph Marrero <jmarrero@fedoraproject.org> - 1.6.2-2
- Fix License, Fix Description, move doc files

* Mon Apr 29 2013 Joseph Marrero <jmarrero@fedoraproject.org> - 1.6.2-1
- initial package
